@@ -53,6 +53,7 @@ namespace LongoMatch.Gui
 		private long segmentStopTime;
 		private bool hasNext;
 		private bool seeking=false;
+		private double[] seeksQueue; 
 		private bool IsPlayingPrevState = false;
 		private float rate=1;
 		private double previousVLevel = 1;
@@ -61,6 +62,7 @@ namespace LongoMatch.Gui
 		//the player.mrl is diferent from the filename as it's an uri eg:file:///foo.avi
 		private string filename = null;
 		protected VolumeWindow vwin;
+		
 				
 #region Constructors		
 		public PlayerBin()
@@ -71,8 +73,18 @@ namespace LongoMatch.Gui
 			vwin.VolumeChanged += new VolumeChangedHandler(OnVolumeChanged);
 			controlsbox.Visible = false;	
 			UnSensitive();
-			timescale.Adjustment.PageIncrement = 0.0001;
+			timescale.Adjustment.PageIncrement = 0.01;
 			timescale.Adjustment.StepIncrement = 0.0001;
+			playbutton.CanFocus = false;
+			prevbutton.CanFocus = false;
+			nextbutton.CanFocus = false;
+			volumebutton.CanFocus = false;
+			timescale.CanFocus = false;
+			vscale1.CanFocus = false;	
+			drawbutton.CanFocus = false;
+			seeksQueue = new double[2];
+			seeksQueue [0] = 0;
+			seeksQueue [1] = 0;
 		}
 		
 #endregion
@@ -173,6 +185,13 @@ namespace LongoMatch.Gui
 			player.Pause();
 		}		
 		
+		public void TogglePlay(){
+			if (player.Playing)
+				Pause();
+			else 
+				Play();
+		}
+		
 		public void SetLogo (string filename){
 			player.Logo=filename;
 		}
@@ -243,6 +262,22 @@ namespace LongoMatch.Gui
 			}
 		}
 		
+		public void StepForward(){
+			SeekFromTimescale(timescale.Value + timescale.Adjustment.PageIncrement);
+		}
+		
+		public void StepBackward(){			
+			SeekFromTimescale(timescale.Value - timescale.Adjustment.PageIncrement);
+		}
+		
+		public void FramerateUp(){
+			vscale1.Adjustment.Value += vscale1.Adjustment.StepIncrement;
+		}
+		
+		public void FramerateDown(){
+			vscale1.Adjustment.Value -= vscale1.Adjustment.StepIncrement;
+		}
+		
 		public void UpdateSegmentStartTime (long start){
 			segmentStartTime = start;
 			player.SegmentStartUpdate(start, GetRateFromScale());
@@ -326,10 +361,24 @@ namespace LongoMatch.Gui
 			playerWidget = (Widget)player;
 			playerWidget.ButtonPressEvent += new ButtonPressEventHandler(OnVideoboxButtonPressEvent);
 			playerWidget.Show();
-			videobox.Add(playerWidget);			
+			videobox.Add(playerWidget);	
 				
 		}
 		
+		private void SeekFromTimescale(double pos){						
+			if (InSegment()){
+				long seekPos = segmentStartTime + (long)(pos*(segmentStopTime-segmentStartTime));
+				player.SeekInSegment(seekPos, GetRateFromScale());	
+				timelabel.Text= TimeString.MSecondsToSecondsString(seekPos) + "/" + 
+					TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
+			}
+			else {
+				player.Position = pos;
+				timelabel.Text= TimeString.MSecondsToSecondsString(player.CurrentTime) + "/" + slength;
+				Rate = 1;				
+			}	
+		}
+		
 #endregion
 		
 #region Callbacks
@@ -384,33 +433,30 @@ namespace LongoMatch.Gui
 		
 		protected virtual void OnTimescaleAdjustBounds(object o, Gtk.AdjustBoundsArgs args)
 		{
-			float pos;		
-				
+			double pos;		
+			
 			if (!seeking){
 				seeking = true;
 				IsPlayingPrevState = player.Playing;
 				player.Tick -= tickHandler;
 				player.Pause();
+				seeksQueue [0] = 0;
+				seeksQueue [1] = 0;
 			}
-				
-			pos = (float)timescale.Value;			
 			
-			if (InSegment()){
-				long seekPos = segmentStartTime + (long)(pos*(segmentStopTime-segmentStartTime));
-				player.SeekInSegment(seekPos, GetRateFromScale());	
-				timelabel.Text= TimeString.MSecondsToSecondsString(seekPos) + "/" + 
-					TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
-			}
-			else {
-				player.Position = pos;
-				timelabel.Text= TimeString.MSecondsToSecondsString(player.CurrentTime) + "/" + slength;
-				Rate = 1;				
-			}			
+			pos = timescale.Value;	
+			seeksQueue[0] = seeksQueue[1];
+			seeksQueue[1] = pos;
+			
+			SeekFromTimescale(pos);		
 		}		
 
 		protected virtual void OnTimescaleValueChanged(object sender, System.EventArgs e)
 		{
 			if (seeking){
+				/* Releasing the timescale always report value different from the real one. 
+				 * We need to cache previous position and seek again to the this position */				
+				SeekFromTimescale(seeksQueue[0]);
 				seeking=false;				
 				player.Tick += tickHandler;
 				if (IsPlayingPrevState)
@@ -521,6 +567,10 @@ namespace LongoMatch.Gui
 		{
 			if(filename == null)
 				return;
+			/* FIXME: The pointer is grabbed when the event box is clicked.
+			 * Make sure to ungrab it in order to avoid clicks outisde the window
+			 * triggering this callback. This should be fixed properly.*/ 
+			Pointer.Ungrab(Gtk.Global.CurrentEventTime);
 			if (!player.Playing)
 				Play();
 			else 
