@@ -63,8 +63,9 @@ namespace LongoMatch.Gui.Component
 		private Gtk.TreeViewColumn nameColumn;
 		private Color[] colors;
 		private bool editing;
+		private bool projectIsLive;
 
-
+		
 		public PlaysTreeView() {
 			Selection.Mode = SelectionMode.Multiple;
 			Selection.SelectFunction = SelectFunction;
@@ -72,6 +73,8 @@ namespace LongoMatch.Gui.Component
 
 			SetMenu();
 			SetCategoriesMenu();
+			ProjectIsLive = false;
+			PlayListLoaded = false;
 
 			colors = new Color[20];
 
@@ -88,6 +91,7 @@ namespace LongoMatch.Gui.Component
 			nameColumn.SetCellDataFunc(nameCell, new Gtk.TreeCellDataFunc(RenderName));
 
 			this.AppendColumn(nameColumn);
+			
 		}
 		
 		new public TreeStore Model{
@@ -103,6 +107,14 @@ namespace LongoMatch.Gui.Component
 			}
 		}
 
+		public bool ProjectIsLive{
+			set{
+				projectIsLive = value;
+				addPLN.Visible = !projectIsLive;
+				snapshot.Visible = !projectIsLive;
+			}
+		}
+		
 		public Color[]  Colors {
 			set {
 				this.colors = value;
@@ -111,7 +123,7 @@ namespace LongoMatch.Gui.Component
 
 		public bool PlayListLoaded {
 			set {
-				addPLN.Sensitive=value;
+				addPLN.Sensitive = value;
 			}
 		}
 
@@ -357,7 +369,8 @@ namespace LongoMatch.Gui.Component
 			this.Model.GetIter(out iter, args.Path);
 			TimeNode tNode = (TimeNode)this.Model.GetValue(iter, 0);
 
-			if (tNode is MediaTimeNode && TimeNodeSelected != null)
+			if (tNode is MediaTimeNode && TimeNodeSelected != null
+			    && !projectIsLive)
 				this.TimeNodeSelected((MediaTimeNode)tNode);
 		}
 
@@ -524,5 +537,9 @@ namespace LongoMatch.Gui.Component
 				PlayersTagged((MediaTimeNode)GetValueFromPath(Selection.GetSelectedRows()[0]), Team.VISITOR);
 		}
 		
+		protected override bool OnKeyPressEvent (Gdk.EventKey evnt)
+		{
+			return false;
+		}		
 	}
 }
