@@ -19,6 +19,7 @@
 //
 
 using System;
+using LongoMatch.Common;
 using LongoMatch.Gui.Component;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.TimeNodes;
@@ -47,6 +48,7 @@ namespace LongoMatch
 		private ButtonsWidget buttonswidget;
 		private PlayListWidget playlist;
 		private PlayerBin player;
+		private CapturerBin capturer;
 		private TimeLineWidget timeline;
 		private ProgressBar videoprogressbar;
 		private NotesWidget notes;
@@ -58,6 +60,8 @@ namespace LongoMatch
 		private TimeNode selectedTimeNode=null;
 		// current proyect in use
 		private Project openedProject;
+		private ProjectType projectType;
+		private Time startTime;
 
 		public EventsManager(PlaysListTreeWidget treewidget, PlayersListTreeWidget localPlayersList, 
 		                     PlayersListTreeWidget visitorPlayersList, TagsTreeWidget tagsTreeWidget,
@@ -84,11 +88,25 @@ namespace LongoMatch
 				openedProject = value;
 			}
 		}
+		
+		public ProjectType OpenedProjectType{
+			set {
+				projectType = value;
+			}
+		}
+		
+		public CapturerBin Capturer{
+			set {
+				capturer = value;
+			}
+		}
 
 		private void ConnectSignals() {
 			//Adding Handlers for each event
 
 			buttonswidget.NewMarkEvent += OnNewMark;
+			buttonswidget.NewMarkStartEvent += OnNewMarkStart;
+			buttonswidget.NewMarkStopEvent += OnNewMarkStop;
 
 			treewidget.TimeNodeChanged += OnTimeNodeChanged;
 			localPlayersList.TimeNodeChanged += OnTimeNodeChanged;
@@ -133,26 +151,40 @@ namespace LongoMatch
 		}
 
 		private void ProcessNewMarkEvent(int section,Time pos) {
-			if (player != null && openedProject != null) {
-				//Getting defualt star and stop gap for the section
-				Time startTime = openedProject.Sections.GetStartTime(section);
-				Time stopTime = openedProject.Sections.GetStopTime(section);
-				// Calculating borders of the segment depnding
-				Time start = pos - startTime;
-				Time stop = pos + stopTime;
-				Time fStart = (start < new Time(0)) ? new Time(0) : start;
-				//La longitud tiene que ser en ms
-				Time length;
-
-				length = new Time((int)player.StreamLength);
-
-				Time fStop = (stop > length) ? length: stop;
-				Pixbuf miniature = player.CurrentMiniatureFrame;
-				MediaTimeNode tn = openedProject.AddTimeNode(section,fStart, fStop,miniature);
-				treewidget.AddPlay(tn,section);
-				tagsTreeWidget.AddPlay(tn);
-				timeline.QueueDraw();
+			Time length, startTime, stopTime, start, stop, fStart, fStop;	
+			
+			if (player == null || openedProject == null)
+				return;
+						
+			//Get the default lead and lag time for the section
+			startTime = openedProject.Sections.GetStartTime(section);
+			stopTime = openedProject.Sections.GetStopTime(section);
+			// Calculating borders of the segment depnding
+			start = pos - startTime;
+			stop = pos + stopTime;
+			fStart = (start < new Time(0)) ? new Time(0) : start;
+			
+			if (projectType == ProjectType.FakeCaptureProject || 
+			    projectType == ProjectType.CaptureProject){
+				fStop = stop;					
 			}
+			else {
+				length = new Time((int)player.StreamLength);
+				fStop = (stop > length) ? length: stop;
+			}	
+			AddNewPlay(fStart, fStop, section);
+		}
+		
+		private void AddNewPlay(Time start, Time stop, int section){
+			Pixbuf miniature;
+			MediaTimeNode tn;
+		
+			miniature = projectType == ProjectType.FakeCaptureProject ?
+				null : player.CurrentMiniatureFrame;
+			tn = openedProject.AddTimeNode(section, start, stop,miniature);
+			treewidget.AddPlay(tn,section);
+			tagsTreeWidget.AddPlay(tn);
+			timeline.QueueDraw();
 		}
 
 		protected virtual void OnProgress(float progress) {
@@ -178,8 +210,8 @@ namespace LongoMatch
 
 			else if (progress == (float)EditorState.ERROR) {
 				MessagePopup.PopupMessage(player, MessageType.Error,
-				                          Catalog.GetString("An error has ocurred in the video editor.")
-				                          +Catalog.GetString("Please, retry again."));
+				                          Catalog.GetString("An error has occurred in the video editor.")
+				                          +Catalog.GetString("Please, try again."));
 				videoprogressbar.Hide();
 			}
 		}
@@ -191,9 +223,41 @@ namespace LongoMatch
 		}
 
 		public virtual void OnNewMark(int i) {
-			Time pos = new Time((int)player.CurrentTime);
+			Time pos;
+			
+			if (projectType == ProjectType.FakeCaptureProject || 
+			    projectType == ProjectType.CaptureProject)
+				pos =  new Time((int)capturer.CurrentTime);
+			else 
+				pos = new Time((int)player.CurrentTime);
 			ProcessNewMarkEvent(i,pos);
 		}
+		
+		public virtual void OnNewMarkStart(){
+			startTime = new Time((int)player.CurrentTime);
+		}
+		
+		public virtual void OnNewMarkStop(int section){
+			int diff;
+			Time stopTime = new Time((int)player.CurrentTime);
+			
+			diff = stopTime.MSeconds - startTime.MSeconds;
+			
+			if (diff < 0){
+				MessagePopup.PopupMessage(buttonswidget, MessageType.Warning,
+				                          Catalog.GetString("The stop time is smaller than the start time."+
+				                                            "The play will not be added."));
+				return;
+			}
+			if (diff < 500){
+				int correction = 500 - diff;
+				if (startTime.MSeconds - correction > 0)
+					startTime = startTime - correction;
+				else 
+					stopTime = stopTime + correction;			
+			} 
+			AddNewPlay(startTime, stopTime, section);		
+		}
 
 		protected virtual void OnTimeNodeSelected(MediaTimeNode tNode)
 		{
@@ -234,9 +298,11 @@ namespace LongoMatch
 			foreach (int player in tNode.VisitorPlayers)
 				visitorPlayersList.DeleteTimeNode(tNode,player);
 			openedProject.DeleteTimeNode(tNode,section);
-			this.player.CloseActualSegment();
-			timeline.QueueDraw();
-			MainClass.DB.UpdateProject(openedProject);
+			if (projectType == ProjectType.FileProject){
+				this.player.CloseActualSegment();
+				MainClass.DB.UpdateProject(openedProject);
+			}
+			timeline.QueueDraw();			
 		}
 
 		protected virtual void OnPlayListNodeAdded(MediaTimeNode tNode)
@@ -357,6 +423,7 @@ namespace LongoMatch
 			foreach (Tag tag in tagger.Tags){
 				openedProject.Tags.AddTag(tag);
 			}
+			tagsTreeWidget.UpdateTagsList();
 			tagger.Destroy();
 		}
 
